bayespy.utils.optimize
======================

.. automodule:: bayespy.utils.optimize

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree: generated/
   
      check_gradient
      minimize
   
   

   
   
   

   
   
   